@@ -2,6 +2,7 @@ from enum import Enum
 from io import StringIO
 import copy
 
+
 class GemTextLineType(Enum):
     Text = 1
     PreformattingToggle = 2
@@ -13,6 +14,7 @@ class GemTextLineType(Enum):
     Heading3 = 8
     Quote = 9
 
+
 class GemTextLine:
     type = GemTextLineType.Text
     text = ""
@@ -42,6 +44,7 @@ class GemTextLine:
         elif self.type == GemTextLineType.Quote:
             return f"> {self.text}\n"
 
+
 class GemText:
     firstLevel1Heading = None # None if it was never set (doesn't occur in text), otherwise a string
     lines = []
@@ -61,6 +64,7 @@ class GemText:
             result.write(line.string())
         return result.getvalue()
 
+
 def parseGemText(gemtext = ""):
     lines = gemtext.splitlines(False)
     result = GemText()
@@ -98,7 +102,7 @@ def parseGemText(gemtext = ""):
         elif line.startswith("#"):
             line = line.removeprefix("#").lstrip()
             gml = GemTextLine(GemTextLineType.Heading1, line, "")
-            if result.firstLevel1Heading == None:
+            if result.firstLevel1Heading is None:
                 result.firstLevel1Heading = line
             result.lines.append(gml)
         elif line.startswith(">"):
@@ -109,4 +113,3 @@ def parseGemText(gemtext = ""):
             gml = GemTextLine(GemTextLineType.Text, line, "")
             result.lines.append(gml)
     return result
-
